OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "无法写入 \"config\" 目录！",
    "This can usually be fixed by giving the webserver write access to the config directory" : "您可以设置 Web 服务器对 config 目录的写权限修复这个问题",
    "See %s" : "查看 %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "或者，如果希望保持 config.php 文件的只读权限，请将 \"config_is_read_only\" 设置为 true。",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "这个通常可以通过赋予写入权限到 config 目录来修复。查看：%s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "或者，如果希望保持 config.php 文件的只读权限，请将 \"config_is_read_only\" 设置为 true。查看 %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "应用%1$s的文件替换不正确。请确认版本与当前服务器兼容。",
    "Sample configuration detected" : "示例配置检测",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接把 config.php 的样例文件直接复制使用。这可能会破坏您的安装。在对 config.php 进行修改之前请先阅读相关文档。",
    "%1$s and %2$s" : "%1$s 和 %2$s",
    "%1$s, %2$s and %3$s" : "%1$s，%2$s 和 %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s，%2$s，%3$s 和 %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s，%2$s，%3$s，%4$s 和 %5$s",
    "Education Edition" : "教育版",
    "Enterprise bundle" : "企业捆绑包",
    "Groupware bundle" : "群组捆绑包",
    "Social sharing bundle" : "社交共享捆绑包",
    "PHP %s or higher is required." : "要求 PHP 版本 %s 或者更高。",
    "PHP with a version lower than %s is required." : "需要版本低于 %s 的PHP。",
    "%sbit or higher PHP required." : "需要 %s 或更高版本的 PHP。",
    "Following databases are supported: %s" : "支持以下数据库：%s",
    "The command line tool %s could not be found" : "命令行工具 %s 未找到",
    "The library %s is not available." : "库文件 %s 不可用",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "库版本 %1$s 高于需要的版本 %2$s - 可用版本 %3$s。",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "库版本 %1$s 低于需要的版本 %2$s - 可用版本 %3$s。",
    "Following platforms are supported: %s" : "支持以下平台：%s",
    "Server version %s or higher is required." : "需要服务器版本 %s 或更高版本。",
    "Server version %s or lower is required." : "需要服务器版本 %s 或更低版本。",
    "Logged in user must be an admin or sub admin" : "当前登录用户必须为管理员或子管理员",
    "Logged in user must be an admin" : "当前登录用户必须为管理员",
    "Wiping of device %s has started" : "设备%s的擦除操作已开始",
    "Wiping of device »%s« has started" : "设备 »%s« 的擦除操作已开始",
    "»%s« started remote wipe" : "»%s« 已开始远程擦除",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "设备或应用程序 »%s« 已开始远程擦除进程。进程完成后您将收到另一封邮件。",
    "Wiping of device %s has finished" : "设备 %s 的擦除已完成",
    "Wiping of device »%s« has finished" : "设备 »%s« 的擦除操作已完成",
    "»%s« finished remote wipe" : "»%s« 已完成远程擦除",
    "Device or application »%s« has finished the remote wipe process." : "设备或应用程序 »%s« 已完成远程擦除进程。",
    "Remote wipe started" : "远程擦除开始",
    "A remote wipe was started on device %s" : "设备%s上一个远程擦除操作已开始",
    "Remote wipe finished" : "远程擦除完成",
    "The remote wipe on %s has finished" : "%s上的远程擦除操作已完成",
    "Authentication" : "验证",
    "Unknown filetype" : "未知的文件类型",
    "Invalid image" : "无效的图像",
    "Avatar image is not square" : "头像图像不是正方形",
    "today" : "今天",
    "tomorrow" : "明天",
    "yesterday" : "昨天",
    "_in %n day_::_in %n days_" : ["%n天内"],
    "_%n day ago_::_%n days ago_" : ["%n 天前"],
    "next month" : "下月",
    "last month" : "上月",
    "_in %n month_::_in %n months_" : ["%n月内"],
    "_%n month ago_::_%n months ago_" : ["%n 月前"],
    "next year" : "明年",
    "last year" : "去年",
    "_in %n year_::_in %n years_" : ["%n年内"],
    "_%n year ago_::_%n years ago_" : ["%n 年前"],
    "_in %n hour_::_in %n hours_" : ["%n小时内"],
    "_%n hour ago_::_%n hours ago_" : ["%n 小时前"],
    "_in %n minute_::_in %n minutes_" : ["%n分钟内"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分钟前"],
    "in a few seconds" : "几秒钟内",
    "seconds ago" : "几秒前",
    "Empty file" : "空文件",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "模块：%s不存在。请在 App 设置中开启或联系管理员。",
    "File name is a reserved word" : "文件名包含敏感字符",
    "File name contains at least one invalid character" : "文件名中存在至少一个非法字符",
    "File name is too long" : "文件名过长",
    "Dot files are not allowed" : "以 . 开头的文件不被允许",
    "Empty filename is not allowed" : "不允许使用空名称",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "无法安装应用\"%s\"，因为无法读取appinfo文件。",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "应用程式 \"%s\" 无法安装，因为它与这个版本的服务器不兼容。",
    "__language_name__" : "简体中文",
    "This is an automatically sent email, please do not reply." : "这是一个自动生成的电子邮件，请不要回复。",
    "Help" : "帮助",
    "Apps" : "应用",
    "Settings" : "设置",
    "Log out" : "登出",
    "Users" : "用户",
    "Unknown user" : "未知用户",
    "Overview" : "概览",
    "Basic settings" : "基本设置",
    "Sharing" : "共享",
    "Security" : "安全",
    "Groupware" : "组件",
    "Additional settings" : "其他设置",
    "Personal info" : "个人信息",
    "Mobile & desktop" : "移动 & 桌面",
    "%s enter the database username and name." : "%s 输入数据库用户名和名称。",
    "%s enter the database username." : "%s 输入数据库用户名。",
    "%s enter the database name." : "%s 输入数据库名称。",
    "%s you may not use dots in the database name" : "%s 您不能在数据库名称中使用英文句号。",
    "Oracle connection could not be established" : "不能建立甲骨文连接",
    "Oracle username and/or password not valid" : "Oracle 数据库用户名和/或密码无效",
    "PostgreSQL username and/or password not valid" : "PostgreSQL 数据库用户名和/或密码无效",
    "You need to enter details of an existing account." : "您需要输入现有账号的详细信息。",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X 不被支持并且 %s 在这个平台上无法正常工作。请自行承担风险！",
    "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起来这个 %s 实例运行在32位PHP环境中并且已在php.ini中配置open_basedir。这将在文件超过4GB时出现问题，我们极力反对这样做。",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "请删除php.ini中的open_basedir设置或切换到64位PHP。",
    "Set an admin username." : "请设置一个管理员用户名。",
    "Set an admin password." : "请设置一个管理员密码。",
    "Can't create or write into the data directory %s" : "无法创建或写入数据目录 %s",
    "Invalid Federated Cloud ID" : "无效的联合云ID",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "共享后端 %s 必须实现 OCP\\Share_Backend 接口",
    "Sharing backend %s not found" : "%s 的共享后端未找到",
    "Sharing backend for %s not found" : "%s 的共享后端未找到",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 与您共享了 »%2$s« 并希望添加：",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s 与您共享了 »%2$s« 并希望添加",
    "»%s« added a note to a file shared with you" : "»%s« 在与您共享的文件中添加了备注",
    "Open »%s«" : "打开 »%s«",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "You are not allowed to share %s" : "您无权共享 %s",
    "Can’t increase permissions of %s" : "无法增加%s的权限。",
    "Files can’t be shared with delete permissions" : "无法共享有删除权限的文件",
    "Files can’t be shared with create permissions" : "无法共享有创建权限的文件",
    "Expiration date is in the past" : "到期日期已过",
    "Can’t set expiration date more than %s days in the future" : "无法将过期日期设置为超过 %s 天。",
    "%1$s shared »%2$s« with you" : "%1$s 对您共享了 »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s 对您共享了 »%2$s«。",
    "Click the button below to open it." : "点击下方按钮可打开它。",
    "The requested share does not exist anymore" : "当前请求的共享已经不存在",
    "Could not find category \"%s\"" : "无法找到分类 \"%s\"",
    "Sunday" : "星期日",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "Sun." : "周日",
    "Mon." : "周一",
    "Tue." : "周二",
    "Wed." : "周三",
    "Thu." : "周四",
    "Fri." : "周五",
    "Sat." : "周六",
    "Su" : "日",
    "Mo" : "一",
    "Tu" : "二",
    "We" : "三",
    "Th" : "四",
    "Fr" : "五",
    "Sa" : "六",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "Jan." : "一月",
    "Feb." : "二月",
    "Mar." : "三月",
    "Apr." : "四月",
    "May." : "五月",
    "Jun." : "六月",
    "Jul." : "七月",
    "Aug." : "八月",
    "Sep." : "九月",
    "Oct." : "十月",
    "Nov." : "十一月",
    "Dec." : "十二月",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "在用户名中只允许使用以下字符：“a-z”，“A-Z”，“0-9”和\"_.@-'\"",
    "A valid username must be provided" : "必须提供合法的用户名",
    "Username contains whitespace at the beginning or at the end" : "用户名在开头或结尾处包含空格",
    "Username must not consist of dots only" : "用户名不能仅由点组成",
    "Username is invalid because files already exist for this user" : "用户名无效，因为该用户已经存在文件",
    "A valid password must be provided" : "必须提供合法的密码",
    "The username is already being used" : "用户名已被使用",
    "Could not create user" : "无法创建用户",
    "User disabled" : "用户已禁用",
    "Login canceled by app" : "已通过应用取消登录",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "应用 \"%1$s\" 无法安装，因为不能满足以下依赖： %2$s",
    "a safe home for all your data" : "给您所有数据一个安全的家",
    "File is currently busy, please try again later" : "文件当前正忙，请稍后再试",
    "Can't read file" : "无法读取文件",
    "Application is not enabled" : "应用程序未启用",
    "Authentication error" : "认证出错",
    "Token expired. Please reload page." : "Token 过期，请刷新页面。",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "没有安装数据库驱动（SQLite、MySQL 或 PostgreSQL）。",
    "Cannot write into \"config\" directory" : "无法写入“config”目录",
    "Cannot write into \"apps\" directory" : "无法写入“apps”目录",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "这个通常可以通过赋予 apps 目录写入权限或者在 config 文件中关闭 AppStore 来修复。详情：%s",
    "Cannot create \"data\" directory" : "无法创建“data”目录 ",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "这个通常可以通过赋予根目录写入权限来修复。查看：%s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "权限通常可以通过赋予根目录写入权限来修复。查看：%s。",
    "Setting locale to %s failed" : "设置语言为 %s 失败",
    "Please install one of these locales on your system and restart your webserver." : "请在您的系统中安装下述一种语言并重启 Web 服务器。",
    "Please ask your server administrator to install the module." : "请联系服务器管理员安装模块。",
    "PHP module %s not installed." : "PHP %s 模块未安装。",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP 选项 \"%s\" 未设置为 \"%s\"。",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "在 php.ini 中调整该设置将导致 Nextcloud 重新运行",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload 当前设置为 \"%s\"，预期值为 \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "请在 php.ini 中设置  <code>mbstring.func_overload</code> 为 <code>0</code> 以解决该问题",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "至少需要 libxml2 2.7.0. 当前安装 %s。",
    "To fix this issue update your libxml2 version and restart your web server." : "升级您的 libxml2 版本然后重启 Web 服务器以解决该问题。",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除内联块，这将导致多个核心应用无法访问。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能由缓存/加速器导致的，例如 Zend OPcache 或 eAccelerator。",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP 模块已经安装，但仍然显示未安装？",
    "Please ask your server administrator to restart the web server." : "请联系服务器管理员重启 Web 服务器。",
    "PostgreSQL >= 9 required" : "要求 PostgreSQL >= 9",
    "Please upgrade your database version" : "请升级您的数据库版本",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "请更改权限为 0770 以避免其他用户查看目录。",
    "Your data directory is readable by other users" : "您的数据目录可被其他用户读取",
    "Your data directory must be an absolute path" : "您的数据目录必须是绝对路径",
    "Check the value of \"datadirectory\" in your configuration" : "请检查配置文件中 \"datadirectory\" 的值",
    "Your data directory is invalid" : "您的数据目录无效",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "请确定在根目录下有一个名为\".ocdata\"的文件。",
    "Action \"%s\" not supported or implemented." : "操作 \"%s\" 不支持或未实现。",
    "Authentication failed, wrong token or provider ID given" : "认证失败，提供了错误的token或提供者ID",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "缺少参数来完成请求。缺少的参数为：\"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" 已被云联合提供商 \"%2$s\" 使用",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID为 \"%s\" 的云联合提供商不存在。",
    "Could not obtain lock type %d on \"%s\"." : "无法在 \"%s\" 上获取锁类型 %d。",
    "Storage unauthorized. %s" : "存储认证失败。%s",
    "Storage incomplete configuration. %s" : "存储未完成配置。%s",
    "Storage connection error. %s" : "存储连接错误。%s",
    "Storage is temporarily not available" : "存储暂时不可用",
    "Storage connection timeout. %s" : "存储连接超时。%s",
    "Create" : "创建",
    "Change" : "修改",
    "Delete" : "删除",
    "Share" : "共享",
    "Unlimited" : "无限制",
    "Verifying" : "验证",
    "Verifying …" : "验证...",
    "Verify" : "验证",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "共享 %s 失败，因为后端不允许共享 %i 类型",
    "Sharing %s failed, because the file does not exist" : "共享 %s 失败，因为文件不存在",
    "Sharing %s failed, because you can not share with yourself" : "共享 %s 失败，因为您不能共享给自己",
    "Sharing %1$s failed, because the user %2$s does not exist" : "共享 %1$s 失败，因为 %2$s 用户不存在",
    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "共享 %1$s失败， 因为用户 %2$s 不是%3$s 所属的任何组的用户",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "共享 %1$s 失败，因为该项已经共享给 %2$s",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "共享 %1$s 失败， 因为该项已经共享给用户 %2$s",
    "Sharing %1$s failed, because the group %2$s does not exist" : "共享 %1$s 失败，因为 %2$s 分组不存在",
    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "共享 %1$s 失败，因为 %2$s 不是 %3$s 分组的成员",
    "You need to provide a password to create a public link, only protected links are allowed" : "您需要提供密码以创建公开链接，因为只允许创建受保护的链接",
    "Sharing %s failed, because sharing with links is not allowed" : "共享 %s 失败，因为不允许使用链接共享",
    "Not allowed to create a federated share with the same user" : "不允许创建对相同用户的联合共享",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "共享 %1$s 失败，无法找到 %2$s，该服务当前无法连接。",
    "Share type %1$s is not valid for %2$s" : "%1$s 不是 %2$s 合法的共享类型",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "无法设置过期时间。过期时间不能晚于其共享时间 %s",
    "Cannot set expiration date. Expiration date is in the past" : "无法设置过期时间。过期时间不能为过去",
    "Sharing failed, because the user %s is the original sharer" : "共享失败，因为用户 %s 是原始的共享者",
    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "共享 %1$s 失败， 因为已经超出了 %2$s 的权限。",
    "Sharing %s failed, because resharing is not allowed" : "共享 %s 失败，因为不允许二次共享",
    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "共享 %1$s失败，因为无法找到 %2$s 共享后端的来源",
    "Sharing %s failed, because the file could not be found in the file cache" : "共享 %s 失败，因为文件缓存中找不到该文件"
},
"nplurals=1; plural=0;");
